summaryrefslogtreecommitdiff
path: root/wsgitools/filters.py
diff options
context:
space:
mode:
Diffstat (limited to 'wsgitools/filters.py')
-rw-r--r--wsgitools/filters.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/wsgitools/filters.py b/wsgitools/filters.py
index 32a0a46..90e7dec 100644
--- a/wsgitools/filters.py
+++ b/wsgitools/filters.py
@@ -283,7 +283,10 @@ class TimerWSGIFilter(BaseWSGIFilter):
__all__.append("EncodeWSGIFilter")
class EncodeWSGIFilter(BaseWSGIFilter):
- """Encodes all body data (no headers) with given charset."""
+ """Encodes all body data (no headers) with given charset.
+ @note: This violates the wsgi standard as it requires unicode objects
+ whereas wsgi mandates the use of str.
+ """
@classmethod
def creator(cls, charset):
"""Returns a function creating EncodeWSGIFilters with a given charset.